#
# Spec file for package zuluCrypt
#
# Copyright © 2011-2015 Francis Banyikwa <mhogomchungu@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

%bcond_without  bundle_tcplay
# FIXME unbundle lxqtwallet, not possible: uses private headers internally
%bcond_without  bundle_lxqtwallet

%global srcname zuluCrypt
%global srcurl  https://github.com/mhogomchungu/%{srcname}

Name:           zulucrypt
Version:        5.0.0
Release:        1%{?dist}
Summary:        Qt GUI front end to cryptsetup

# major license is GPLv2+ or GPLv3+, BSD for bundled md5, lxqt_wallet and tcplay
License:        GPLv2+ and BSD
URL:            https://mhogomchungu.github.io/%{srcname}
Source0:        %{srcurl}/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  gcc-c++

BuildRequires:  kf5-rpm-macros
BuildRequires:  cmake(KF5Wallet)
BuildRequires:  cmake(KF5Notifications)

BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(libsecret-1)

BuildRequires:  device-mapper-devel
BuildRequires:  glibc-devel
BuildRequires:  libblkid-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libpwquality-devel
BuildRequires:  cryptsetup-devel

#BuildRequires:  chrpath

BuildRequires:  desktop-file-utils

Provides:       bundled(md5-openssl)
%if %{with bundle_tcplay}
Provides:       bundled(tcplay) = 2.0
%else
BuildRequires:  tcplay-devel >= 2.0
%endif
%if %{with bundle_lxqtwallet}
Provides:       bundled(lxqt-wallet) = 2.2.1
%else
BuildRequires:  pkgconfig(lxqtwallet) >= 2.2.1
%endif

Requires:       %{name}-libs%{?_isa} = %{version}-%{release}
Requires:       hicolor-icon-theme

%description
zuluCrypt is a front end to cryptsetup.
It makes it easier to use cryptsetup by providing
a Qt-based GUI and a simpler to use CLI front end
to cryptsetup.
It does the same thing truecrypt does but without
licensing problems or requiring a user to setup
sudo for it or presenting root's password.
This package contains the applications.

%package libs
Summary:        Library for %{name}

%description libs
This package contains libraries that provide higher
level access to cryptsetup API and provide
mounting/unmounting API to easy opening and closing
of volume.

%package devel
Summary:        Development files for %{name}
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
This package contains development files and
libraries necessary to build programs around
zulucrypt.

%package doc
Summary:        Additional documentation files for %{name}
BuildArch:      noarch

%description doc
%{summary}.

###################################################################################
%prep
%autosetup -n%{srcname}-%{version}
# documentation
mv 'ABOUT ME' AUTHORS
sed -i /docs/d CMakeLists.txt
# drop rpath, https://fedoraproject.org/wiki/Packaging:Guidelines#Beware_of_Rpath
find . -name CMakeLists.txt |xargs sed -i /INSTALL_RPATH/d

# unbundling
%if %{without bundle_tcplay}
rm -rf external_libraries/tc-play/*
ln -s %{_includedir}/*.h external_libraries/tc-play
sed -i -r 's:(STATIC_TCPLAY ").*":\1false":' CMakeLists.txt
%endif
%if %{without bundle_lxqtwallet}
rm -rf %{srcname}-gui/lxqt_wallet
sed -i /lxqt_wallet/d CMakeLists.txt
find . -name CMakeLists.txt |xargs sed -i 's:\.\./%{srcname}-gui/lxqt_wallet/.*\.c::'
find . -name \*.c |xargs sed -i -r \
 's:(include )".*%{srcname}-gui/lxqt_wallet.*/(.*.h)":\1\<lxqt/\2>:'
find . -name \*.h |xargs sed -i -r \
 's:(include )".*%{srcname}-gui/lxqt_wallet.*/(.*.h)":\1\<lxqt/\2>:'
echo TARGET_LINK_LIBRARIES\( zuluCryptKeyServer lxqtwallet \) \
 >>%{srcname}-cli/CMakeLists.txt
mkdir -p %{_target_platform}
cat <<EOT >>%{_target_platform}/storage_manager.h
#define HAS_SECRET_SUPPORT 1
#define HAS_KWALLET_SUPPORT 1
EOT
%endif

%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
%{cmake_kf5} \
 -DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name} \
 -DREUSEMOUNTPOINT=false \
 -DUDEVSUPPORT=true \
 -DNOGUI=false \
 -DQT5=true \
 -DHOMEMOUNTPREFIX=false \
 -DNOGNOME=false \
 -DNOKDE=false \
 ..
popd
%make_build -C %{_target_platform}

%install
%make_install -C %{_target_platform}
# be tolerant about rpath
#chrpath --delete %{buildroot}%{_bindir}/zulu* %{buildroot}%{_libdir}/%{srcname}/*

%if 0
# collect translations into right folder
mv %{buildroot}%{_datadir}/%{srcname} %{buildroot}%{_datadir}/%{name}
%find_lang %{name}-gui --with-qt
%endif

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/zulu*.desktop

###################################################################################
%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null ||: ;

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null ;
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null ||: ;
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null ||: ;

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

###################################################################################
%files
# -f %%{name}.lang
%license COPYING GPLv* LICENSE
%doc AUTHORS *README* TODO changelog
%{_bindir}/zulu*
%{_datadir}/applications/zulu*.desktop
%{_datadir}/icons/hicolor/*/apps/zulu*.png
%{_datadir}/pixmaps/zulu*.png
%{_mandir}/man1/zulu*.1*
# FIXME install translation files into right place
%dir %{_datadir}/%{srcname}
%{_datadir}/%{srcname}/translations/

%files libs
%license COPYING GPLv* LICENSE
%{_libdir}/libzulu*.so.*
%{_libdir}/%{srcname}/

%files devel
%{_includedir}/%{srcname}/
%{_libdir}/libzulu*.so
%{_libdir}/pkgconfig/libzulu*.pc

%files doc
%license COPYING GPLv* LICENSE
%doc docs/*.pdf
%doc docs/README docs/*.jpg images/*.jpeg

###################################################################################
%changelog
* Thu Jul 14 2016 Raphael Groner <projects.rg@smart.ms> - 5.0.0-1
- adjust for Fedora, based on upstream spec file
- unbundle tcplay
- try to unbundle lxqtwallet (unfinished)

* Thu May  1 2014 Francis Banyikwa <mhogomchungu@gmail.com> - 5.0.0-0
- version 5.0.0

* Fri Mar 15 2013 Francis Banyikwa <mhogomchungu@gmail.com> - 4.6.2-0
- upate to version 4.6.2

* Sat Jan 14 2012 Francis Banyikwa <mhogomchungu@gmail.com> - 4.6.0-0
- update to version 4.6.0

